@@ -25,6 +25,7 @@
 
 #include <KWindowSystem/KWindowInfo>
 #include <KWindowSystem>
+#include <KX11Extras>
 
 #include <kquickaddons/quickviewsharedengine.h>
 
@@ -256,10 +257,7 @@ void DialogPrivate::updateTheme()
             frameSvgItem->setImagePath(prefix + QStringLiteral("dialogs/background"));
         }
 
-        // This makes the mask slightly maller than the frame. Since the svg will have antialiasing and the mask not,
-        // there will be artifacts at the corners, if they go under the svg they're less evident
-        frameSvgItem->frameSvg()->resizeFrame(q->size() - QSize(2, 2));
-        const QRegion mask = frameSvgItem->frameSvg()->mask().translated(1, 1);
+        const QRegion mask = frameSvgItem->frameSvg()->mask();
         KWindowEffects::enableBlurBehind(q, theme.blurBehindEnabled(), mask);
 
         KWindowEffects::enableBackgroundContrast(q,
@@ -268,9 +266,8 @@ void DialogPrivate::updateTheme()
                                                  theme.backgroundIntensity(),
                                                  theme.backgroundSaturation(),
                                                  mask);
-        frameSvgItem->frameSvg()->resizeFrame(q->size());
 
-        if (KWindowSystem::compositingActive()) {
+        if (KX11Extras::compositingActive()) {
             if (hasMask) {
                 hasMask = false;
                 q->setMask(QRegion());
@@ -910,9 +907,9 @@ void DialogPrivate::applyType()
     }
 
     if (type == Dialog::Dock || type == Dialog::Notification || type == Dialog::OnScreenDisplay || type == Dialog::CriticalNotification) {
-        KWindowSystem::setOnAllDesktops(q->winId(), true);
+        KX11Extras::setOnAllDesktops(q->winId(), true);
     } else {
-        KWindowSystem::setOnAllDesktops(q->winId(), false);
+        KX11Extras::setOnAllDesktops(q->winId(), false);
     }
 
 #if HAVE_KWAYLAND
